Base58

Struct Base58 

pub struct Base58<ALPHABET: Alphabet = Standard>(/* private fields */);
Available on crate feature base58 only.
Serialize bytes with base58

The type serializes a sequence of bytes as a base58 string. It works on any type implementing AsRef<[u8]> for serialization and TryFrom<Vec<u8>> for deserialization.

The type allows customizing the character set. The ALPHABET is a type implementing Alphabet.

use serde_with::base58::{Base58, Flickr};

#[serde_as]
#[derive(Serialize, Deserialize)]
struct B58 {
    // The default is the same as Standard character set
    #[serde_as(as = "Base58")]
    default: Vec<u8>,
    // Change the character set
    #[serde_as(as = "Base58<Flickr>")]
    charset_flickr: Vec<u8>,
}

let b58 = B58 {
    default: b"Hello World".to_vec(),
    charset_flickr: b"Hello World".to_vec(),
};
let json = serde_json::json!({
    "default": "JxF12TrwUP45BMd",
    "charset_flickr": "iXf12sRWto45bmC",
});

// Test serialization and deserialization
assert_eq!(json, serde_json::to_value(&b58).unwrap());
assert_eq!(b58, serde_json::from_value(json).unwrap());