pub struct SetPreventDuplicates<T>(/* private fields */);Available on crate feature
alloc only.Expand description
Ensure no duplicate values exist in a set.
By default serde has a last-value-wins implementation, if duplicate values for a set exist. Sometimes it is desirable to know when such an event happens, as the first value is overwritten and it can indicate an error in the serialized data.
This helper returns an error if two identical values exist in a set.
The implementation supports both the HashSet and the BTreeSet from the standard library.
Example
#[serde_as]
#[derive(Deserialize)]
struct Doc {
#[serde_as(as = "SetPreventDuplicates<_>")]
set: HashSet<usize>,
}
// Sets are serialized normally,
let s = r#"{"set": [1, 2, 3, 4]}"#;
let v = Doc {
set: HashSet::from_iter(vec![1, 2, 3, 4]),
};
assert_eq!(v, serde_json::from_str(s).unwrap());
// but create an error if duplicate values, like the `1`, exist.
let s = r#"{"set": [1, 2, 3, 4, 1]}"#;
let res: Result<Doc, _> = serde_json::from_str(s);
assert!(res.is_err());Trait Implementations
Sourceimpl<'de, T, TAs> DeserializeAs<'de, BTreeSet<T>> for SetPreventDuplicates<TAs>where
TAs: DeserializeAs<'de, T>,
T: Ord,
impl<'de, T, TAs> DeserializeAs<'de, BTreeSet<T>> for SetPreventDuplicates<TAs>where
TAs: DeserializeAs<'de, T>,
T: Ord,
Sourcefn deserialize_as<D>(deserializer: D) -> Result<BTreeSet<T>, D::Error>where
D: Deserializer<'de>,
fn deserialize_as<D>(deserializer: D) -> Result<BTreeSet<T>, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer.
Sourceimpl<'de, T, TAs, S> DeserializeAs<'de, HashSet<T, S>> for SetPreventDuplicates<TAs>
impl<'de, T, TAs, S> DeserializeAs<'de, HashSet<T, S>> for SetPreventDuplicates<TAs>
Sourcefn deserialize_as<D>(deserializer: D) -> Result<HashSet<T, S>, D::Error>where
D: Deserializer<'de>,
fn deserialize_as<D>(deserializer: D) -> Result<HashSet<T, S>, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer.
Sourceimpl<'de, T, TAs, S> DeserializeAs<'de, HashSet<T, S>> for SetPreventDuplicates<TAs>
impl<'de, T, TAs, S> DeserializeAs<'de, HashSet<T, S>> for SetPreventDuplicates<TAs>
Sourcefn deserialize_as<D>(deserializer: D) -> Result<HashbrownSet014<T, S>, D::Error>where
D: Deserializer<'de>,
fn deserialize_as<D>(deserializer: D) -> Result<HashbrownSet014<T, S>, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer.
Sourceimpl<'de, T, TAs, S> DeserializeAs<'de, HashSet<T, S>> for SetPreventDuplicates<TAs>
impl<'de, T, TAs, S> DeserializeAs<'de, HashSet<T, S>> for SetPreventDuplicates<TAs>
Sourcefn deserialize_as<D>(deserializer: D) -> Result<HashbrownSet015<T, S>, D::Error>where
D: Deserializer<'de>,
fn deserialize_as<D>(deserializer: D) -> Result<HashbrownSet015<T, S>, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer.
Sourceimpl<'de, T, TAs, S> DeserializeAs<'de, HashSet<T, S>> for SetPreventDuplicates<TAs>
impl<'de, T, TAs, S> DeserializeAs<'de, HashSet<T, S>> for SetPreventDuplicates<TAs>
Sourcefn deserialize_as<D>(deserializer: D) -> Result<HashbrownSet016<T, S>, D::Error>where
D: Deserializer<'de>,
fn deserialize_as<D>(deserializer: D) -> Result<HashbrownSet016<T, S>, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer.
Sourceimpl<'de, T, TAs, S> DeserializeAs<'de, IndexSet<T, S>> for SetPreventDuplicates<TAs>
impl<'de, T, TAs, S> DeserializeAs<'de, IndexSet<T, S>> for SetPreventDuplicates<TAs>
Sourcefn deserialize_as<D>(deserializer: D) -> Result<IndexSet<T, S>, D::Error>where
D: Deserializer<'de>,
fn deserialize_as<D>(deserializer: D) -> Result<IndexSet<T, S>, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer.
Sourceimpl<'de, T, TAs, S> DeserializeAs<'de, IndexSet<T, S>> for SetPreventDuplicates<TAs>
impl<'de, T, TAs, S> DeserializeAs<'de, IndexSet<T, S>> for SetPreventDuplicates<TAs>
Sourcefn deserialize_as<D>(deserializer: D) -> Result<IndexSet2<T, S>, D::Error>where
D: Deserializer<'de>,
fn deserialize_as<D>(deserializer: D) -> Result<IndexSet2<T, S>, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer.
Sourceimpl<V, VA> JsonSchemaAs<BTreeSet<V>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature schemars_0_8 only.
impl<V, VA> JsonSchemaAs<BTreeSet<V>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature
schemars_0_8 only.Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl<V, VA> JsonSchemaAs<BTreeSet<V>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature schemars_0_9 only.
impl<V, VA> JsonSchemaAs<BTreeSet<V>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature
schemars_0_9 only.Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON schemas generated for this type should be included directly
in arent schemas, rather than being re-used where possible using the
$ref
keyword. Read moreSourceimpl<V, VA> JsonSchemaAs<BTreeSet<V>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature schemars_1 only.
impl<V, VA> JsonSchemaAs<BTreeSet<V>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature
schemars_1 only.Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON schemas generated for this type should be included directly
in arent schemas, rather than being re-used where possible using the
$ref
keyword. Read moreSourceimpl<V, S, VA> JsonSchemaAs<HashSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature schemars_0_8 only.
impl<V, S, VA> JsonSchemaAs<HashSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature
schemars_0_8 only.Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl<V, S, VA> JsonSchemaAs<HashSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature schemars_0_8 only.
impl<V, S, VA> JsonSchemaAs<HashSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature
schemars_0_8 only.Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl<V, S, VA> JsonSchemaAs<HashSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature schemars_1 only.
impl<V, S, VA> JsonSchemaAs<HashSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature
schemars_1 only.Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON schemas generated for this type should be included directly
in arent schemas, rather than being re-used where possible using the
$ref
keyword. Read moreSourceimpl<V, S, VA> JsonSchemaAs<HashSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature schemars_1 only.
impl<V, S, VA> JsonSchemaAs<HashSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature
schemars_1 only.Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON schemas generated for this type should be included directly
in arent schemas, rather than being re-used where possible using the
$ref
keyword. Read moreSourceimpl<V, S, VA> JsonSchemaAs<HashSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature schemars_0_8 only.
impl<V, S, VA> JsonSchemaAs<HashSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature
schemars_0_8 only.Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl<V, S, VA> JsonSchemaAs<HashSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature schemars_0_8 only.
impl<V, S, VA> JsonSchemaAs<HashSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature
schemars_0_8 only.Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl<V, S, VA> JsonSchemaAs<HashSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature schemars_0_9 only.
impl<V, S, VA> JsonSchemaAs<HashSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature
schemars_0_9 only.Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON schemas generated for this type should be included directly
in arent schemas, rather than being re-used where possible using the
$ref
keyword. Read moreSourceimpl<V, S, VA> JsonSchemaAs<HashSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature schemars_0_9 only.
impl<V, S, VA> JsonSchemaAs<HashSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature
schemars_0_9 only.Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON schemas generated for this type should be included directly
in arent schemas, rather than being re-used where possible using the
$ref
keyword. Read moreSourceimpl<V, S, VA> JsonSchemaAs<HashSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature schemars_0_9 only.
impl<V, S, VA> JsonSchemaAs<HashSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature
schemars_0_9 only.Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON schemas generated for this type should be included directly
in arent schemas, rather than being re-used where possible using the
$ref
keyword. Read moreSourceimpl<V, S, VA> JsonSchemaAs<HashSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature schemars_0_9 only.
impl<V, S, VA> JsonSchemaAs<HashSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature
schemars_0_9 only.Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON schemas generated for this type should be included directly
in arent schemas, rather than being re-used where possible using the
$ref
keyword. Read moreSourceimpl<V, S, VA> JsonSchemaAs<HashSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature schemars_1 only.
impl<V, S, VA> JsonSchemaAs<HashSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature
schemars_1 only.Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON schemas generated for this type should be included directly
in arent schemas, rather than being re-used where possible using the
$ref
keyword. Read moreSourceimpl<V, S, VA> JsonSchemaAs<HashSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature schemars_1 only.
impl<V, S, VA> JsonSchemaAs<HashSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature
schemars_1 only.Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON schemas generated for this type should be included directly
in arent schemas, rather than being re-used where possible using the
$ref
keyword. Read moreSourceimpl<V, S, VA> JsonSchemaAs<IndexSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature schemars_0_8 only.
impl<V, S, VA> JsonSchemaAs<IndexSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature
schemars_0_8 only.Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl<V, S, VA> JsonSchemaAs<IndexSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature schemars_0_8 only.
impl<V, S, VA> JsonSchemaAs<IndexSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature
schemars_0_8 only.Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl<V, S, VA> JsonSchemaAs<IndexSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature schemars_0_9 only.
impl<V, S, VA> JsonSchemaAs<IndexSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature
schemars_0_9 only.Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON schemas generated for this type should be included directly
in arent schemas, rather than being re-used where possible using the
$ref
keyword. Read moreSourceimpl<V, S, VA> JsonSchemaAs<IndexSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature schemars_0_9 only.
impl<V, S, VA> JsonSchemaAs<IndexSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature
schemars_0_9 only.Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON schemas generated for this type should be included directly
in arent schemas, rather than being re-used where possible using the
$ref
keyword. Read moreSourceimpl<V, S, VA> JsonSchemaAs<IndexSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature schemars_1 only.
impl<V, S, VA> JsonSchemaAs<IndexSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature
schemars_1 only.Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON schemas generated for this type should be included directly
in arent schemas, rather than being re-used where possible using the
$ref
keyword. Read moreSourceimpl<V, S, VA> JsonSchemaAs<IndexSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature schemars_1 only.
impl<V, S, VA> JsonSchemaAs<IndexSet<V, S>> for SetPreventDuplicates<VA>where
VA: JsonSchemaAs<V>,
Available on crate feature
schemars_1 only.Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON schemas generated for this type should be included directly
in arent schemas, rather than being re-used where possible using the
$ref
keyword. Read moreSourceimpl<T, TAs> SerializeAs<BTreeSet<T>> for SetPreventDuplicates<TAs>where
TAs: SerializeAs<T>,
impl<T, TAs> SerializeAs<BTreeSet<T>> for SetPreventDuplicates<TAs>where
TAs: SerializeAs<T>,
Sourcefn serialize_as<S>(
value: &BTreeSet<T>,
serializer: S,
) -> Result<S::Ok, S::Error>where
S: Serializer,
fn serialize_as<S>(
value: &BTreeSet<T>,
serializer: S,
) -> Result<S::Ok, S::Error>where
S: Serializer,
Serialize this value into the given Serde serializer.
Sourceimpl<T, TAs, H> SerializeAs<HashSet<T, H>> for SetPreventDuplicates<TAs>
impl<T, TAs, H> SerializeAs<HashSet<T, H>> for SetPreventDuplicates<TAs>
Sourcefn serialize_as<S>(
value: &HashSet<T, H>,
serializer: S,
) -> Result<S::Ok, S::Error>where
S: Serializer,
fn serialize_as<S>(
value: &HashSet<T, H>,
serializer: S,
) -> Result<S::Ok, S::Error>where
S: Serializer,
Serialize this value into the given Serde serializer.
Sourceimpl<T, TAs, H> SerializeAs<HashSet<T, H>> for SetPreventDuplicates<TAs>
impl<T, TAs, H> SerializeAs<HashSet<T, H>> for SetPreventDuplicates<TAs>
Sourcefn serialize_as<S>(
value: &HashbrownSet014<T, H>,
serializer: S,
) -> Result<S::Ok, S::Error>where
S: Serializer,
fn serialize_as<S>(
value: &HashbrownSet014<T, H>,
serializer: S,
) -> Result<S::Ok, S::Error>where
S: Serializer,
Serialize this value into the given Serde serializer.
Sourceimpl<T, TAs, H> SerializeAs<HashSet<T, H>> for SetPreventDuplicates<TAs>
impl<T, TAs, H> SerializeAs<HashSet<T, H>> for SetPreventDuplicates<TAs>
Sourcefn serialize_as<S>(
value: &HashbrownSet015<T, H>,
serializer: S,
) -> Result<S::Ok, S::Error>where
S: Serializer,
fn serialize_as<S>(
value: &HashbrownSet015<T, H>,
serializer: S,
) -> Result<S::Ok, S::Error>where
S: Serializer,
Serialize this value into the given Serde serializer.
Sourceimpl<T, TAs, H> SerializeAs<HashSet<T, H>> for SetPreventDuplicates<TAs>
impl<T, TAs, H> SerializeAs<HashSet<T, H>> for SetPreventDuplicates<TAs>
Sourcefn serialize_as<S>(
value: &HashbrownSet016<T, H>,
serializer: S,
) -> Result<S::Ok, S::Error>where
S: Serializer,
fn serialize_as<S>(
value: &HashbrownSet016<T, H>,
serializer: S,
) -> Result<S::Ok, S::Error>where
S: Serializer,
Serialize this value into the given Serde serializer.
Sourceimpl<T, TAs, H> SerializeAs<IndexSet<T, H>> for SetPreventDuplicates<TAs>
impl<T, TAs, H> SerializeAs<IndexSet<T, H>> for SetPreventDuplicates<TAs>
Sourcefn serialize_as<S>(
value: &IndexSet<T, H>,
serializer: S,
) -> Result<S::Ok, S::Error>where
S: Serializer,
fn serialize_as<S>(
value: &IndexSet<T, H>,
serializer: S,
) -> Result<S::Ok, S::Error>where
S: Serializer,
Serialize this value into the given Serde serializer.
Sourceimpl<T, TAs, H> SerializeAs<IndexSet<T, H>> for SetPreventDuplicates<TAs>
impl<T, TAs, H> SerializeAs<IndexSet<T, H>> for SetPreventDuplicates<TAs>
Sourcefn serialize_as<S>(
value: &IndexSet2<T, H>,
serializer: S,
) -> Result<S::Ok, S::Error>where
S: Serializer,
fn serialize_as<S>(
value: &IndexSet2<T, H>,
serializer: S,
) -> Result<S::Ok, S::Error>where
S: Serializer,
Serialize this value into the given Serde serializer.